# The JWST Rogue Path Tool

Module to predict the presence of the stray-light artifacts know as claws in NIRCam Imaging observations.

## Installation for Users

To install `jwst_rogue_path_tool`, simply use `pip`:

```
pip install jwst_rogue_path_tool
```

To install from source:
1. Clone Git Repository
```
git clone git@github.com:spacetelescope/jwst_rogue_path_tool.git
```
2. Install requirements
```
pip install .
```

## Outputs

<img src="docs/_static/exposure_plot_program_0_obs_id_3.png">

<img src="docs/_static/0_1_ALL_100.png">

<img src="docs/_static/v3pa_vs_flux_0_5_B.png">
